==> upload-api-client-internal-2.41.0.tgz: package/src/models/JobSummary.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { AccountId } from "./AccountId";
import type { AccountJobId } from "./AccountJobId";
import type { AccountJobStatus } from "./AccountJobStatus";
import type { AccountJobType } from "./AccountJobType";
import type { EpochMillis } from "./EpochMillis";
import type { JsonObject } from "./JsonObject";

/**
 * Summary information about an asynchronous background job (for example, a folder deletion).
 */
export type JobSummary = {
  accountId: AccountId;
  /**
   * The number of times the job has been executed. Once the job has been successfully executed, no further attempts will be made.
   */
  attempts: number;
  /**
   * The time this job was created in epoch milliseconds (since midnight 1 January 1970, UTC).
   */
  created: EpochMillis;
  error: {
    /**
     * Human-readable error message.
     */
    message: string;
    /**
     * Additional machine-readable details relating to the error.
     */
    details?: any;
    /**
     * Machine-readable error code.
     */
    code: string;
  } | null;
  /**
   * The job's unique ID.
   */
  jobId: AccountJobId;
  /**
   * The type of the job.
   */
  jobType: AccountJobType;
  /**
   * The time this job was created, or the last time the `status` / `attempts` fields were updated, in epoch milliseconds (since midnight 1 January 1970, UTC).
   */
  lastUpdated: EpochMillis;
  /**
   * The `payload` and `jobType` define the work the job will perform / has performed.
   */
  payload: JsonObject;
  /**
   * The job's status.
   */
  status: AccountJobStatus;
};

==> upload-api-client-internal-2.55.0.tgz: package/src/models/JobSummary.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { AccountId } from "./AccountId";
import type { AccountJobId } from "./AccountJobId";
import type { AccountJobStatus } from "./AccountJobStatus";
import type { AccountJobType } from "./AccountJobType";
import type { EpochMillis } from "./EpochMillis";
import type { JsonObject } from "./JsonObject";

/**
 * Summary information about an asynchronous background job (for example, a folder deletion).
 */
export type JobSummary = {
  accountId: AccountId;
  /**
   * The number of times the job has been executed. Once the job has been successfully executed, no further attempts will be made.
   */
  attempts: number;
  /**
   * The time this job was created in epoch milliseconds (since midnight 1 January 1970, UTC).
   */
  created: EpochMillis;
  error: {
    /**
     * Human-readable error message.
     */
    message: string;
    /**
     * Additional machine-readable details relating to the error.
     */
    details?: any;
    /**
     * Machine-readable error code.
     */
    code: string;
  } | null;
  /**
   * The job's unique ID.
   */
  jobId: AccountJobId;
  /**
   * The type of the job.
   */
  jobType: AccountJobType;
  /**
   * The time this job was created, or the last time the `status` / `attempts` fields were updated, in epoch milliseconds (since midnight 1 January 1970, UTC).
   */
  lastUpdated: EpochMillis;
  /**
   * The `payload` and `jobType` together define the work the job will perform / has performed.
   */
  payload: JsonObject;
  /**
   * The job's status.
   */
  status: AccountJobStatus;
};
